==> zio-aws-ec2_2.13-5.17.127.2-sources.jar: zio/aws/ec2/model/LaunchTemplateInstanceMetadataOptions.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class LaunchTemplateInstanceMetadataOptions(
    state: Option[
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptionsState
    ] = None,
    httpTokens: Option[zio.aws.ec2.model.LaunchTemplateHttpTokensState] = None,
    httpPutResponseHopLimit: Option[Integer] = None,
    httpEndpoint: Option[
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataEndpointState
    ] = None,
    httpProtocolIpv6: Option[
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataProtocolIpv6
    ] = None,
    instanceMetadataTags: Option[
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataTagsState
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LaunchTemplateInstanceMetadataOptions = {
    import LaunchTemplateInstanceMetadataOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LaunchTemplateInstanceMetadataOptions
      .builder()
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(httpTokens.map(value => value.unwrap))(_.httpTokens)
      .optionallyWith(
        httpPutResponseHopLimit.map(value =>
          Integer.unwrap(value): java.lang.Integer
        )
      )(_.httpPutResponseHopLimit)
      .optionallyWith(httpEndpoint.map(value => value.unwrap))(_.httpEndpoint)
      .optionallyWith(httpProtocolIpv6.map(value => value.unwrap))(
        _.httpProtocolIpv6
      )
      .optionallyWith(instanceMetadataTags.map(value => value.unwrap))(
        _.instanceMetadataTags
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions.ReadOnly =
    zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions
      .wrap(buildAwsValue())
}
object LaunchTemplateInstanceMetadataOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LaunchTemplateInstanceMetadataOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions =
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions(
        state.map(value => value),
        httpTokens.map(value => value),
        httpPutResponseHopLimit.map(value => value),
        httpEndpoint.map(value => value),
        httpProtocolIpv6.map(value => value),
        instanceMetadataTags.map(value => value)
      )
    def state
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptionsState]
    def httpTokens: Option[zio.aws.ec2.model.LaunchTemplateHttpTokensState]
    def httpPutResponseHopLimit: Option[Integer]
    def httpEndpoint
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataEndpointState]
    def httpProtocolIpv6
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataProtocolIpv6]
    def instanceMetadataTags
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataTagsState]
    def getState: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptionsState
    ] = AwsError.unwrapOptionField("state", state)
    def getHttpTokens
        : ZIO[Any, AwsError, zio.aws.ec2.model.LaunchTemplateHttpTokensState] =
      AwsError.unwrapOptionField("httpTokens", httpTokens)
    def getHttpPutResponseHopLimit: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("httpPutResponseHopLimit", httpPutResponseHopLimit)
    def getHttpEndpoint: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataEndpointState
    ] = AwsError.unwrapOptionField("httpEndpoint", httpEndpoint)
    def getHttpProtocolIpv6: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataProtocolIpv6
    ] = AwsError.unwrapOptionField("httpProtocolIpv6", httpProtocolIpv6)
    def getInstanceMetadataTags: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataTagsState
    ] = AwsError.unwrapOptionField("instanceMetadataTags", instanceMetadataTags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateInstanceMetadataOptions
  ) extends zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions.ReadOnly {
    override val state
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptionsState] =
      scala
        .Option(impl.state())
        .map(value =>
          zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptionsState
            .wrap(value)
        )
    override val httpTokens
        : Option[zio.aws.ec2.model.LaunchTemplateHttpTokensState] = scala
      .Option(impl.httpTokens())
      .map(value => zio.aws.ec2.model.LaunchTemplateHttpTokensState.wrap(value))
    override val httpPutResponseHopLimit: Option[Integer] = scala
      .Option(impl.httpPutResponseHopLimit())
      .map(value => zio.aws.ec2.model.primitives.Integer(value))
    override val httpEndpoint: Option[
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataEndpointState
    ] = scala
      .Option(impl.httpEndpoint())
      .map(value =>
        zio.aws.ec2.model.LaunchTemplateInstanceMetadataEndpointState
          .wrap(value)
      )
    override val httpProtocolIpv6
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataProtocolIpv6] =
      scala
        .Option(impl.httpProtocolIpv6())
        .map(value =>
          zio.aws.ec2.model.LaunchTemplateInstanceMetadataProtocolIpv6
            .wrap(value)
        )
    override val instanceMetadataTags
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataTagsState] =
      scala
        .Option(impl.instanceMetadataTags())
        .map(value =>
          zio.aws.ec2.model.LaunchTemplateInstanceMetadataTagsState.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateInstanceMetadataOptions
  ): zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-ec2_2.13-5.17.130.5-sources.jar: zio/aws/ec2/model/LaunchTemplateInstanceMetadataOptions.scala <==
package zio.aws.ec2.model
import zio.aws.ec2.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class LaunchTemplateInstanceMetadataOptions(
    state: Option[
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptionsState
    ] = None,
    httpTokens: Option[zio.aws.ec2.model.LaunchTemplateHttpTokensState] = None,
    httpPutResponseHopLimit: Option[Integer] = None,
    httpEndpoint: Option[
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataEndpointState
    ] = None,
    httpProtocolIpv6: Option[
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataProtocolIpv6
    ] = None,
    instanceMetadataTags: Option[
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataTagsState
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ec2.model.LaunchTemplateInstanceMetadataOptions = {
    import LaunchTemplateInstanceMetadataOptions.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ec2.model.LaunchTemplateInstanceMetadataOptions
      .builder()
      .optionallyWith(state.map(value => value.unwrap))(_.state)
      .optionallyWith(httpTokens.map(value => value.unwrap))(_.httpTokens)
      .optionallyWith(
        httpPutResponseHopLimit.map(value => value: java.lang.Integer)
      )(_.httpPutResponseHopLimit)
      .optionallyWith(httpEndpoint.map(value => value.unwrap))(_.httpEndpoint)
      .optionallyWith(httpProtocolIpv6.map(value => value.unwrap))(
        _.httpProtocolIpv6
      )
      .optionallyWith(instanceMetadataTags.map(value => value.unwrap))(
        _.instanceMetadataTags
      )
      .build()
  }
  def asReadOnly
      : zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions.ReadOnly =
    zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions
      .wrap(buildAwsValue())
}
object LaunchTemplateInstanceMetadataOptions {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ec2.model.LaunchTemplateInstanceMetadataOptions
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions =
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions(
        state.map(value => value),
        httpTokens.map(value => value),
        httpPutResponseHopLimit.map(value => value),
        httpEndpoint.map(value => value),
        httpProtocolIpv6.map(value => value),
        instanceMetadataTags.map(value => value)
      )
    def state
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptionsState]
    def httpTokens: Option[zio.aws.ec2.model.LaunchTemplateHttpTokensState]
    def httpPutResponseHopLimit: Option[Integer]
    def httpEndpoint
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataEndpointState]
    def httpProtocolIpv6
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataProtocolIpv6]
    def instanceMetadataTags
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataTagsState]
    def getState: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptionsState
    ] = AwsError.unwrapOptionField("state", state)
    def getHttpTokens
        : ZIO[Any, AwsError, zio.aws.ec2.model.LaunchTemplateHttpTokensState] =
      AwsError.unwrapOptionField("httpTokens", httpTokens)
    def getHttpPutResponseHopLimit: ZIO[Any, AwsError, Integer] = AwsError
      .unwrapOptionField("httpPutResponseHopLimit", httpPutResponseHopLimit)
    def getHttpEndpoint: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataEndpointState
    ] = AwsError.unwrapOptionField("httpEndpoint", httpEndpoint)
    def getHttpProtocolIpv6: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataProtocolIpv6
    ] = AwsError.unwrapOptionField("httpProtocolIpv6", httpProtocolIpv6)
    def getInstanceMetadataTags: ZIO[
      Any,
      AwsError,
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataTagsState
    ] = AwsError.unwrapOptionField("instanceMetadataTags", instanceMetadataTags)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateInstanceMetadataOptions
  ) extends zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions.ReadOnly {
    override val state
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptionsState] =
      scala
        .Option(impl.state())
        .map(value =>
          zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptionsState
            .wrap(value)
        )
    override val httpTokens
        : Option[zio.aws.ec2.model.LaunchTemplateHttpTokensState] = scala
      .Option(impl.httpTokens())
      .map(value => zio.aws.ec2.model.LaunchTemplateHttpTokensState.wrap(value))
    override val httpPutResponseHopLimit: Option[Integer] =
      scala.Option(impl.httpPutResponseHopLimit()).map(value => value: Integer)
    override val httpEndpoint: Option[
      zio.aws.ec2.model.LaunchTemplateInstanceMetadataEndpointState
    ] = scala
      .Option(impl.httpEndpoint())
      .map(value =>
        zio.aws.ec2.model.LaunchTemplateInstanceMetadataEndpointState
          .wrap(value)
      )
    override val httpProtocolIpv6
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataProtocolIpv6] =
      scala
        .Option(impl.httpProtocolIpv6())
        .map(value =>
          zio.aws.ec2.model.LaunchTemplateInstanceMetadataProtocolIpv6
            .wrap(value)
        )
    override val instanceMetadataTags
        : Option[zio.aws.ec2.model.LaunchTemplateInstanceMetadataTagsState] =
      scala
        .Option(impl.instanceMetadataTags())
        .map(value =>
          zio.aws.ec2.model.LaunchTemplateInstanceMetadataTagsState.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.ec2.model.LaunchTemplateInstanceMetadataOptions
  ): zio.aws.ec2.model.LaunchTemplateInstanceMetadataOptions.ReadOnly =
    new Wrapper(impl)
}
